<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Clean Business
 */

function clean_business_get_option( $value ) {
	return get_theme_mod( $value, clean_business_get_default_theme_options( $value ) );
}
add_filter( 'clean_business_get_option', 'clean_business_get_option' );


/**
 * Flush out all transients
 *
 * @uses delete_transient
 *
 * @action customize_save, clean_business_customize_preview (see clean_business_customizer function: clean_business_customize_preview)
 *
 * @since Clean Business 1.0
 */
function clean_business_flush_transients(){
	delete_transient( 'clean_business_featured_content' );

	delete_transient( 'clean_business_featured_slider' );

	delete_transient( 'clean_business_custom_css' );

	delete_transient( 'clean_business_footer_content' );

	delete_transient( 'clean_business_featured_image' );

	delete_transient( 'clean_business_social_icons' );

	delete_transient( 'clean_business_scrollup' );

	delete_transient( 'all_the_cool_cats' );
}
add_action( 'customize_save', 'clean_business_flush_transients' );


/**
 * Flush out post related transients
 *
 * @uses delete_transient
 *
 * @action save_post
 *
 * @since Clean Business 1.0
 */
function clean_business_flush_post_transients(){
	delete_transient( 'clean_business_featured_content' );

	delete_transient( 'clean_business_featured_slider' );

	delete_transient( 'clean_business_featured_image' );

	delete_transient( 'all_the_cool_cats' );
}
add_action( 'save_post', 'clean_business_flush_post_transients' );


/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function clean_business_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	$layout = clean_business_get_theme_layout();

	switch ( $layout ) {
		case 'left-sidebar':
			$classes[] = 'two-columns content-right';
		break;

		case 'right-sidebar':
			$classes[] = 'two-columns content-left';
		break;

		case 'no-sidebar':
			$classes[] = 'no-sidebar content-width';
		break;

		case 'no-sidebar-one-column':
			$classes[] = 'no-sidebar one-column';
		break;

		case 'no-sidebar-full-width':
			$classes[] = 'no-sidebar full-width';
		break;
	}

	$classes[] = apply_filters( 'clean_business_get_option', 'content_layout' );

	global $post, $wp_query;
	$enable_slider 	= apply_filters( 'clean_business_get_option', 'featured_slider_option' );

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	$slider_disabled = true;

	//Check if slider is inactive
	 if( 'entire-site' == $enable_slider || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable_slider ) ) {
	 	$slider_disabled = false;
	 }

	//Check if header image is enabled
	$header_image_disabled = false;

	$enable_header_image = apply_filters( 'clean_business_get_option', 'enable_featured_header_image' );

	// Check Enable/Disable header image in Page/Post Meta box
	if ( is_page() || is_single() ) {
		//Individual Page/Post Image Setting
		$individual_featured_image = get_post_meta( $post->ID, 'clean-business-header-image', true );

     	if ( 'disabled' == $individual_featured_image || ( ( '' == $individual_featured_image || 'default' == $individual_featured_image ) && 'disabled' == $enable_header_image ) ) {
			$header_image_disabled = true;
		}
	}

	if( 'disabled' == $enable_header_image ) {
		$header_image_disabled = true;
	}
	// Check Homepage
	elseif ( 'homepage' == $enable_header_image && !( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) ) {
		$header_image_disabled = true;
	}
	// Check Excluding Homepage
	if ( 'exclude-home' == $enable_header_image && ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) ) {
		$header_image_disabled = true;
	}
	elseif ( 'exclude-home-page-post' == $enable_header_image && ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) ) {
		$header_image_disabled = true;
	}
	// Check Page/Post
	elseif ( 'pages-posts' ==  $enable_header_image && ( !( is_page() || is_single() ) ) ) {
		$header_image_disabled = true;
	}

	if ( $slider_disabled && $header_image_disabled ) {
		//Add class if both slider and header image is  disabled
		$classes[] = 'header-bg';
	}

	$classes[] = apply_filters( 'clean_business_get_option', 'color_scheme' );

	return $classes;
}
add_filter( 'body_class', 'clean_business_body_classes' );

if ( ! function_exists( 'clean_business_post_classes' ) ) :
	/**
	 * Adds clean business post classes to the array of post classes.
	 * used for supporting different content layouts
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_post_classes( $classes ) {
		$content_layout = apply_filters( 'clean_business_get_option', 'content_layout' );

		if ( is_archive() || is_home() ) {
			$classes[] = $content_layout;
		}

		return $classes;
	}
endif; //clean_business_post_classes
add_filter( 'post_class', 'clean_business_post_classes' );

if ( ! function_exists( 'clean_business_get_comment_section' ) ) :
	/**
	 * Comment Section
	 *
	 * @get comment setting from theme options and display comments sections accordingly
	 * @display comments_template
	 * @action clean_business_comment_section
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_get_comment_section() {
		$comment_option = apply_filters( 'clean_business_get_option', 'comment_option' );

		if ( 'use-wordpress-setting' == $comment_option ) {
			if ( comments_open() || '0' != get_comments_number() )
				comments_template();
		}
		else if ( 'disable-in-pages' == $comment_option ) {
			if( ! is_page() ){
				if ( comments_open() || '0' != get_comments_number() ){
					comments_template();
				}
			}
		}
}
endif;
add_action( 'clean_business_comment_section', 'clean_business_get_comment_section', 10 );

if ( ! function_exists( 'clean_business_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since Clean Business 1.0
	 */
	function clean_business_comment_form_fields( $fields ) {
		$disable_website_field = apply_filters( 'clean_business_get_option', 'disable_website_field' );

		if ( isset( $fields['url'] ) && $disable_website_field ) {
			unset( $fields['url'] );
		}

		return $fields;

	}
endif; //clean_business_comment_form_fields
add_filter( 'comment_form_default_fields', 'clean_business_comment_form_fields' );

if ( ! function_exists( 'clean_business_custom_css' ) ) :
	/**
	 * Enqueue Custon CSS
	 *
	 * @uses  set_transient, wp_head, wp_enqueue_style
	 *
	 * @action wp_enqueue_scripts
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_custom_css() {
		//clean_business_flush_transients();

		if ( ( !$custom_css = get_transient( 'clean_business_custom_css' ) ) ) {
			$defaults      = clean_business_get_default_theme_options();
			$defaults_temp = $defaults;
			$custom_css    ='';

			$color_scheme = apply_filters( 'clean_business_get_option', 'color_scheme' );
			//Change values of default colors if the scheme is dark
			if ( 'dark' == $color_scheme ) {
				$defaults_dark = $defaults = clean_business_default_dark_color_options();

				$defaults['featured_content_background_color'] = $defaults_dark['featured_content_background_color'];
			}

			//Basic Color Options
			//Get all color values
			$color_headings = apply_filters( 'clean_business_color_options', 'color_headings' );

			foreach ( $color_headings as $key_heading => $value_heading ) {
				$color_options	= apply_filters( 'clean_business_color_options', $key_heading );

				foreach ( $color_options as $key => $value ) {
					$options[ $key ] = apply_filters( 'clean_business_get_option', $key );
				}
			}

			$text_color = get_header_textcolor();

			if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $text_color ) {
				$custom_css	.=  ".site-title a, .site-description { color: #".  esc_attr( $text_color ) ."; }". "\n";
			}

			if( $defaults['text_color'] != $options['text_color'] ) {
				$custom_css	.=  "body { color: ". esc_attr( $options['text_color'] ) ."; }". "\n";
			}

			if( $defaults['link_color'] != $options['link_color'] ) {
				$custom_css	.=  "a { color: ". esc_attr( $options['link_color'] ) ."; }". "\n";
			}

			if( $defaults['link_hover_color'] != $options['link_hover_color'] ) {
				$custom_css	.=  "a:hover, a:focus, a:active { color: ". esc_attr( $options['link_hover_color'] ) ."; }". "\n";
			}

			//Header Color Options
			if( $defaults['header_background_color'] != $options['header_background_color'] ) {
				$custom_css	.=  "#masthead { background-color: ". esc_attr( $options['header_background_color'] ) ."; }". "\n";
			}

			if( $defaults['site_title_hover_color'] != $options['site_title_hover_color'] ) {
				$custom_css	.=  ".site-title a:hover, .site-title a:focus { color: ". esc_attr( $options['site_title_hover_color'] ) ."; }". "\n";
			}

			if( $defaults['tagline_color'] != $options['tagline_color'] ) {
				$custom_css	.=  ".site-description { color: ". esc_attr( $options['tagline_color'] ) ."; }". "\n";
			}

			// Primary Menu Color
			if( ( $defaults['menu_background_color'] != $options['menu_background_color'] )
			|| ( $defaults['menu_color'] != $options['menu_color'] )
			|| ( $defaults['hover_active_background_color'] != $options['hover_active_background_color'] )
			|| ( $defaults['hover_active_text_color'] != $options['hover_active_text_color'] )
			|| ( $defaults['sub_menu_background_color'] != $options['sub_menu_background_color'] )
			|| ( $defaults['sub_menu_text_color'] != $options['sub_menu_text_color'] )
			|| ( $defaults['sub_menu_hover_active_background_color'] != $options['sub_menu_hover_active_background_color'] )
			|| ( $defaults['sub_menu_hover_active_text_color'] != $options['sub_menu_hover_active_text_color'] ) ) {
				$custom_css	.=  "#mainnav { background-color: ". esc_attr( $options['menu_background_color'] ) ."; }". "\n";

				$custom_css	.=  "#mainnav ul li a { color: ". esc_attr( $options['menu_color'] ) ."; }". "\n";

				$custom_css	.=  "#mainnav .current_page_item > a, #mainnav .current_page_ancestor > a, #mainnav .current-menu-item > a, #mainnav .current-menu-ancestor > a { background-color: ". esc_attr( $options['hover_active_background_color'] ) ."; color: ". esc_attr( $options['hover_active_text_color'] ) ."; }". "\n";

				$custom_css	.=  "#mainnav .sub-menu li a, #mainnav .children li a { background-color: ". esc_attr( $options['sub_menu_background_color'] ) ."; color: ". esc_attr( $options['sub_menu_text_color'] ) ."; }". "\n";

				$custom_css	.=  "#mainnav .sub-menu li:hover > a, #mainnav .children li:hover > a, #mainnav .sub-menu li:focus > a, #mainnav .children li:focus > a { background-color: ". esc_attr( $options['sub_menu_hover_active_background_color'] ) ."; color: ". esc_attr( $options['sub_menu_hover_active_text_color'] ) ."; }". "\n";
			}

			//Content Color Options
			if( $defaults['content_wrapper_background_color'] != $options['content_wrapper_background_color'] ) {
				$custom_css	.=  "#content { background-color: ". esc_attr( $options['content_wrapper_background_color'] ) ."; }". "\n";
			}

			if( $defaults['content_background_color'] != $options['content_background_color'] || $defaults['content_border_color'] != $options['content_border_color'] ) {
				$custom_css	.=  ".content-area .hentry { background-color: ". esc_attr( $options['content_background_color'] ) ."; border-color: ". esc_attr( $options['content_border_color'] ) ."; }". "\n";
			}

			if( $defaults['content_title_color'] != $options['content_title_color'] ) {
				$custom_css	.=  ".content-area .entry-title, .content-area .entry-title a { color: ". esc_attr( $options['content_title_color'] ) ."; }". "\n";
			}

			if( $defaults['content_title_hover_color'] != $options['content_title_hover_color'] ) {
				$custom_css	.=  ".content-area .entry-title a:hover, .content-area .entry-title a:focus { color: ". esc_attr( $options['content_title_hover_color'] ) ."; }". "\n";
			}

			if( $defaults['content_meta_color'] != $options['content_meta_color'] ) {
				$custom_css	.=  ".meta-post, .meta-post a, .entry-meta, .entry-meta a { color: ". esc_attr( $options['content_meta_color'] ) ."; }". "\n";
			}

			if( $defaults['content_meta_hover_color'] != $options['content_meta_hover_color'] ) {
				$custom_css	.=  ".meta-post a:hover, .meta-post a:focus, .entry-meta a:hover, .entry-meta a:focus { color: ". esc_attr( $options['content_meta_hover_color'] ) ."; }". "\n";
			}

			//Sidebar Color Options
			if( $defaults['sidebar_background_color'] != $options['sidebar_background_color'] || $defaults['sidebar_border_color'] != $options['sidebar_border_color'] ) {
				$custom_css	.=  "#secondary { background-color: ". esc_attr( $options['sidebar_background_color'] ) ."; border-color: ". esc_attr( $options['sidebar_border_color'] ) ."; }". "\n";
			}

			if( $defaults['sidebar_widget_title_color'] != $options['sidebar_widget_title_color'] ) {
				$custom_css	.=  ".widget-area .widget-title { color: ". esc_attr( $options['sidebar_widget_title_color'] ) ."; }". "\n";
			}

			if( $defaults['sidebar_widget_text_color'] != $options['sidebar_widget_text_color'] ) {
				$custom_css	.=  ".widget-area { color: ". esc_attr( $options['sidebar_widget_text_color'] ) ."; }". "\n";
			}

			if( $defaults['sidebar_widget_link_color'] != $options['sidebar_widget_link_color'] ) {
				$custom_css	.=  ".widget-area a { color: ". esc_attr( $options['sidebar_widget_link_color'] ) ."; }". "\n";
			}

			if( $defaults['sidebar_widget_link_hover_color'] != $options['sidebar_widget_link_hover_color'] ) {
				$custom_css	.=  ".widget-area a:hover, .widget-area a:focus  { color: ". esc_attr( $options['sidebar_widget_link_hover_color'] ) ."; }". "\n";
			}

			//Pagination Color Options
			if( $defaults['pagination_background_color'] != $options['pagination_background_color'] || $defaults['pagination_text_color'] != $options['pagination_text_color'] ) {
				$custom_css	.=  ".posts-navigation .nav-links a, .pagination .nav-links a, .site-main #infinite-handle span button { background-color: ". esc_attr( $options['pagination_background_color'] ) ."; color: ". esc_attr( $options['pagination_text_color'] ) ."; }". "\n";
			}

			if( $defaults['pagination_border_color'] != $options['pagination_border_color'] ) {
				$custom_css	.=  ".posts-navigation .nav-links a, .pagination .nav-links a, .site-main #infinite-handle span button { border-color: ". esc_attr( $options['pagination_border_color'] ) ."; }". "\n";
			}

			if( $defaults['pagination_hover_background_color'] != $options['pagination_hover_background_color'] || $defaults['pagination_hover_text_color'] != $options['pagination_hover_text_color'] ) {
				$custom_css	.=  ".posts-navigation .nav-links a:hover, .posts-navigation .nav-links a:focus, .pagination .nav-links a:hover, .pagination .nav-links a:focus, .pagination .nav-links .current, .wp-pagenavi span.current, .wp-pagenavi a:hover, .wp-pagenavi a:focus, .site-main #infinite-handle span button:hover, .site-main #infinite-handle span button:focus { background-color: ". esc_attr( $options['pagination_hover_background_color'] ) ."; color: ". esc_attr( $options['pagination_hover_text_color'] ) ."; }". "\n";
			}

			if( $defaults['pagination_hover_border_color'] != $options['pagination_hover_border_color'] ) {
				$custom_css	.=  ".posts-navigation .nav-links a:hover, .posts-navigation .nav-links a:focus, .pagination .nav-links a:hover, .pagination .nav-links a:focus, .pagination .nav-links .current, .wp-pagenavi span.current, .wp-pagenavi a:hover, .wp-pagenavi a:focus, .site-main #infinite-handle span button:hover, .site-main #infinite-handle span button:focus { border-color: ". esc_attr( $options['pagination_hover_border_color'] ) ."; }". "\n";
			}

			//Promotion Headline Color Options
			if( ( $defaults['promotion_headline_background_color'] != $options['promotion_headline_background_color'] ) || ( $defaults['promotion_headline_text_color'] != $options['promotion_headline_text_color'] ) ) {
				$custom_css	.=  "#promotion-message { background-color: ". esc_attr( $options['promotion_headline_background_color'] ) ."; color: ". esc_attr( $options['promotion_headline_text_color'] ) .";  }". "\n";
			}

			if( $defaults['promotion_headline_title_color'] != $options['promotion_headline_title_color'] ) {
				$custom_css	.=  "#promotion-message .entry-title { color: ". esc_attr( $options['promotion_headline_title_color'] ) ."; }". "\n";
			}

			if( $defaults['promotion_headline_link_color'] != $options['promotion_headline_link_color'] ) {
				$custom_css	.=  "#promotion-message a { color: ". esc_attr( $options['promotion_headline_link_color'] ) ."; }". "\n";
			}

			if( $defaults['promotion_headline_button_background_color'] != $options['promotion_headline_button_background_color'] || $defaults['promotion_headline_button_border_color'] != $options['promotion_headline_button_border_color'] || $defaults['promotion_headline_button_text_color'] != $options['promotion_headline_button_text_color'] ) {
				$custom_css	.=  "#promotion-message .more-button { background-color: ". esc_attr( $options['promotion_headline_button_background_color'] ) ."; border-color: ". esc_attr( $options['promotion_headline_button_border_color'] ) ."; color: ". esc_attr( $options['promotion_headline_button_text_color'] ) ."; }". "\n";
			}

			if( $defaults['promotion_headline_button_hover_background_color'] != $options['promotion_headline_button_hover_background_color'] || $defaults['promotion_headline_button_hover_border_color'] != $options['promotion_headline_button_hover_border_color'] || $defaults['promotion_headline_button_hover_text_color'] != $options['promotion_headline_button_hover_text_color'] ) {
				$custom_css	.=  "#promotion-message .more-button:hover, #promotion-message .more-button:focus { background-color: ". esc_attr( $options['promotion_headline_button_hover_background_color'] ) ."; border-color: ". esc_attr( $options['promotion_headline_button_hover_border_color'] ) ."; color: ". esc_attr( $options['promotion_headline_button_hover_text_color'] ) ."; }". "\n";
			}

			//Slider Color Options
			if( $defaults['slider_title_color'] != $options['slider_title_color'] ) {
				$custom_css	.=  ".text-slider .entry-title { color: ". esc_attr( $options['slider_title_color'] ) ."; }". "\n";
			}

			if( $defaults['slider_text_color'] != $options['slider_text_color'] ) {
				$custom_css	.=  ".text-slider .subtitle { color: ". esc_attr( $options['slider_text_color'] ) ."; }". "\n";
			}

			if( $defaults['slider_link_color'] != $options['slider_link_color'] ) {
				$custom_css	.=  ".text-slider .subtitle a { color: ". esc_attr( $options['slider_link_color'] ) ."; }". "\n";
			}

			if( $defaults['slider_link_hover_color'] != $options['slider_link_hover_color'] ) {
				$custom_css	.=  ".text-slider .subtitle a:hover, .text-slider .subtitle a:focus { color: ". esc_attr( $options['slider_link_hover_color'] ) ."; }". "\n";
			}

			if( $defaults['slider_button_background_color'] != $options['slider_button_background_color'] || $defaults['slider_button_border_color'] != $options['slider_button_border_color'] || $defaults['slider_button_text_color'] != $options['slider_button_text_color'] ) {
				$custom_css	.=  "#slideshow .roll-button { background-color: ". esc_attr( $options['slider_button_background_color'] ) ."; border-color: ". esc_attr( $options['slider_button_border_color'] ) ."; color: ". esc_attr( $options['slider_button_text_color'] ) ."; }". "\n";
			}

			if( $defaults['slider_button_hover_background_color'] != $options['slider_button_hover_background_color'] || $defaults['slider_button_hover_border_color'] != $options['slider_button_hover_border_color'] || $defaults['slider_button_hover_text_color'] != $options['slider_button_hover_text_color'] ) {
				$custom_css	.=  "#slideshow .roll-button:hover, #slideshow .roll-button:focus { background-color: ". esc_attr( $options['slider_button_hover_background_color'] ) ."; border-color: ". esc_attr( $options['slider_button_hover_border_color'] ) ."; color: ". esc_attr( $options['slider_button_hover_text_color'] ) ."; }". "\n";
			}

			//Featured Content Color Options
			if( $defaults['featured_content_title_color'] != $options['featured_content_title_color'] ) {
				$custom_css	.=  "#featured-content .entry-title, #featured-content .entry-title a { color: ". esc_attr( $options['featured_content_title_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_title_hover_color'] != $options['featured_content_title_hover_color'] ) {
				$custom_css	.=  "#featured-content .entry-title:hover, #featured-content .entry-title a:hover, #featured-content .entry-title:focus, #featured-content .entry-title a:focus { color: ". esc_attr( $options['featured_content_title_hover_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_text_color'] != $options['featured_content_text_color'] ) {
				$custom_css	.=  "#featured-content { color: ". esc_attr( $options['featured_content_text_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_link_color'] != $options['featured_content_link_color'] ) {
				$custom_css	.=  "#featured-content a { color: ". esc_attr( $options['featured_content_link_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_link_hover_color'] != $options['featured_content_link_hover_color'] ) {
				$custom_css	.=  "#featured-content a:hover, #featured-content a:focus  { color: ". esc_attr( $options['featured_content_link_hover_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_button_background_color'] != $options['featured_content_button_background_color'] || $defaults['featured_content_button_border_color'] != $options['featured_content_button_border_color'] || $defaults['featured_content_button_text_color'] != $options['featured_content_button_text_color'] ) {
				$custom_css	.=  "#featured-content .roll-button { background-color: ". esc_attr( $options['featured_content_button_background_color'] ) ."; border-color: ". esc_attr( $options['featured_content_button_border_color'] ) ."; color: ". esc_attr( $options['featured_content_button_text_color'] ) ."; }". "\n";
			}

			if( $defaults['featured_content_button_hover_background_color'] != $options['featured_content_button_hover_background_color'] || $defaults['featured_content_button_hover_border_color'] != $options['featured_content_button_hover_border_color'] || $defaults['featured_content_button_hover_text_color'] != $options['featured_content_button_hover_text_color'] ) {
				$custom_css	.=  "#featured-content .roll-button:hover, #featured-content .roll-button:focus { background-color: ". esc_attr( $options['featured_content_button_hover_background_color'] ) ."; border-color: ". esc_attr( $options['featured_content_button_hover_border_color'] ) ."; color: ". esc_attr( $options['featured_content_button_hover_text_color'] ) ."; }". "\n";
			}

			//Footer Color Options
			if( $defaults['footer_sidebar_background_color'] != $options['footer_sidebar_background_color'] ) {
				$custom_css	.=  ".footer-widgets { background-color: ". esc_attr( $options['footer_sidebar_background_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_sidebar_title_color'] != $options['footer_sidebar_title_color'] ) {
				$custom_css	.=  ".footer-widgets .widget-title, .footer-widgets .widget-title a { color: ". esc_attr( $options['footer_sidebar_title_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_sidebar_text_color'] != $options['footer_sidebar_text_color'] ) {
				$custom_css	.=  ".footer-widgets.widget-area { color: ". esc_attr( $options['footer_sidebar_text_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_sidebar_link_color'] != $options['footer_sidebar_link_color'] ) {
				$custom_css	.=  ".footer-widgets.widget-area a { color: ". esc_attr( $options['footer_sidebar_link_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_sidebar_link_hover_color'] != $options['footer_sidebar_link_hover_color'] ) {
				$custom_css	.=  ".footer-widgets.widget-area a:hover, .footer-widgets.widget-area a:focus { color: ". esc_attr( $options['footer_sidebar_link_hover_color'] ) ."; }". "\n";
			}

			if( ( $defaults['footer_background_color'] != $options['footer_background_color'] ) || ( $defaults['footer_text_color'] != $options['footer_text_color'] ) ) {
				$custom_css	.=  ".site-footer { background-color: ". esc_attr( $options['footer_background_color'] ) ."; color: ". esc_attr( $options['footer_text_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_link_color'] != $options['footer_link_color'] ) {
				$custom_css	.=  ".site-footer a { color: ". esc_attr( $options['footer_link_color'] ) ."; }". "\n";
			}

			if( $defaults['footer_link_hover_color'] != $options['footer_link_hover_color'] ) {
				$custom_css	.=  ".site-footer a:hover, .site-footer a:focus { color: ". esc_attr( $options['footer_link_hover_color'] ) ."; }". "\n";
			}

			//Scrollup Color Options
			if( $defaults['scrollup_background_color'] != $options['scrollup_background_color'] || $defaults['scrollup_border_color'] != $options['scrollup_border_color'] || $defaults['scrollup_text_color'] != $options['scrollup_text_color'] ) {
				$custom_css	.=  ".scrollup { background-color: ". esc_attr( $options['scrollup_background_color'] ) ."; border-color: ". esc_attr( $options['scrollup_border_color'] ) ."; color: ". esc_attr( $options['scrollup_text_color'] ) ."; }". "\n";
			}

			if( $defaults['scrollup_hover_background_color'] != $options['scrollup_hover_background_color'] || $defaults['scrollup_hover_border_color'] != $options['scrollup_hover_border_color'] || $defaults['scrollup_hover_text_color'] != $options['scrollup_hover_text_color'] ) {
				$custom_css	.=  ".scrollup:hover, .scrollup:focus { background-color: ". esc_attr( $options['scrollup_hover_background_color'] ) ."; border-color: ". esc_attr( $options['scrollup_hover_border_color'] ) ."; color: ". esc_attr( $options['scrollup_hover_text_color'] ) ."; }". "\n";
			}

			//Revert values of default to its originals if the value is changed due to dark color scheme
			$defaults 	= $defaults_temp;

			// Typography (Font Family) Options
			$options['body_font']          = apply_filters( 'clean_business_get_option', 'body_font' );
			$options['title_font']         = apply_filters( 'clean_business_get_option', 'title_font' );
			$options['tagline_font']       = apply_filters( 'clean_business_get_option', 'tagline_font' );
			$options['content_title_font'] = apply_filters( 'clean_business_get_option', 'content_title_font' );
			$options['content_font']       = apply_filters( 'clean_business_get_option', 'content_font' );
			$options['headings_font']      = apply_filters( 'clean_business_get_option', 'headings_font' );

			$fonts = clean_business_avaliable_fonts();

			if( $defaults['body_font'] != $options['body_font'] ) {
				$custom_css	.=  "body, button, input, select, textarea { font-family: ". $fonts [ $options['body_font'] ] [ 'label'] ."; }". "\n";
			}
			if( $defaults['title_font'] != $options['title_font'] ) {
				$custom_css	.=  ".site-title { font-family: ". $fonts[ $options['title_font'] ] [ 'label'] ."; }". "\n";
			}
			if( $defaults['tagline_font'] != $options['tagline_font'] ) {
				$custom_css	.=  ".site-description { font-family: ". $fonts[ $options['tagline_font'] ] [ 'label'] ."; }". "\n";
			}
			if( $defaults['content_title_font'] != $options['content_title_font'] ) {
				$custom_css	.=  ".page-title, #main .entry-container .entry-title, #featured-content .entry-title { font-family: ". $fonts[ $options['content_title_font'] ] [ 'label'] ."; }". "\n";
			}
			if( $defaults['content_font'] != $options['content_font'] ) {
				$custom_css	.=  "#main .entry-container, #featured-content { font-family: ". $fonts[ $options['content_font'] ] [ 'label'] ."; }". "\n";
			}
			if( $defaults['headings_font'] != $options['headings_font'] ) {
				$custom_css	.=  "h1, h2, h3, h4, h5, h6 { font-family: ". $fonts[ $options['headings_font'] ] [ 'label'] ."; }". "\n";
			}

			// Featured Content Background Image Options
			$options['featured_content_background_color']    = apply_filters( 'clean_business_get_option', 'featured_content_background_color' );
			$options['featured_content_bg_image']            = apply_filters( 'clean_business_get_option', 'featured_content_bg_image' );
			$options['featured_content_bg_display_position'] = apply_filters( 'clean_business_get_option', 'featured_content_bg_display_position' );
			$options['featured_content_bg_repeat']           = apply_filters( 'clean_business_get_option', 'featured_content_bg_repeat' );
			$options['featured_content_bg_attachment']       = apply_filters( 'clean_business_get_option', 'featured_content_bg_attachment' );

			if( $defaults['featured_content_background_color'] != $options['featured_content_background_color']
				|| $defaults['featured_content_bg_image'] != $options['featured_content_bg_image']
				|| $defaults['featured_content_bg_display_position'] != $options['featured_content_bg_display_position']
				|| $defaults['featured_content_bg_repeat'] != $options['featured_content_bg_repeat']
				|| $defaults['featured_content_bg_attachment'] != $options['featured_content_bg_attachment']
			) {

				$custom_css .= "#featured-content {". "\n";

				if( $defaults['featured_content_background_color'] != $options['featured_content_background_color'] ) {
					$custom_css	.= "background-color: ". esc_attr( $options['featured_content_background_color'] ) . ";". "\n";
				}

				if( $defaults['featured_content_bg_image'] != $options['featured_content_bg_image'] ) {
					$custom_css	.= "background-image: url(\"". esc_url( $options['featured_content_bg_image'] ) ."\");". "\n";
				}

				if( $defaults['featured_content_bg_display_position'] != $options['featured_content_bg_display_position'] ) {
					$custom_css	.=  "background-position: center ". esc_attr( $options['featured_content_bg_display_position'] ) .";". "\n";
				}

				if( $defaults['featured_content_bg_repeat'] != $options['featured_content_bg_repeat'] ) {
					$custom_css	.=  "background-repeat: ". esc_attr( $options['featured_content_bg_repeat'] ) . ";\n";
					$custom_css	.=  "background-size: inherit;\n";
				}

				if( $defaults['featured_content_bg_attachment'] != $options['featured_content_bg_attachment'] ) {
					$custom_css	.=  "background-attachment: ". esc_attr( $options['featured_content_bg_attachment'] ) ."\n";
				}
				$custom_css .= "}";
			}

			/*
			 * Promotion Headline Widget left and right width
			 */
			$options['promotion_headline_left_width'] = apply_filters( 'clean_business_get_option', 'promotion_headline_left_width' );

			if( $defaults['promotion_headline_left_width'] != $options['promotion_headline_left_width'] ) {
				$custom_css	.= "@media screen and (min-width: 481px) {". "\n";
				if ( 100 == $options['promotion_headline_left_width'] ) {
					$custom_css	.=  "#promotion-message .left, #promotion-message .right { max-width: 100%; width: 100%; }". "\n";
					$custom_css	.=  "#promotion-message .right .promotion-button { margin-top: 0; }". "\n";
				}
				else {
					$custom_css	.=  "#promotion-message .left { max-width: ". esc_attr( $options['promotion_headline_left_width'] ) ."%; }". "\n";
					$custom_css	.=  "#promotion-message .right { max-width: ". absint( 100 - $options['promotion_headline_left_width'] ) ."%; }". "\n";
				}
				$custom_css	.= "}". "\n";
			}

			/*
			 * Custom css for genericon social icons. needs change: @change
			 */
			$options['social_icon_size']	= apply_filters( 'clean_business_get_option', 'social_icon_size' );

			if( $defaults['social_icon_size'] != $options['social_icon_size'] )
			if( isset( $options['social_icon_size'] ) && $options['social_icon_size'] != '' ){
				$size = $options['social_icon_size'];

				$custom_css .= '.widget_clean_business_social_icons .genericon:before { font-size:'. esc_attr( $size ) .'px; }' . "\n";
				$custom_css .= '.site .widget_clean_business_social_icons a.genericon { height:'. esc_attr( $size ) .'px; width:'. esc_attr( $size ) .'px; }' . "\n";
			}

			//Custom CSS Option
			$options['custom_css']	= apply_filters( 'clean_business_get_option', 'custom_css' );

			if( !empty( $options['custom_css'] ) ) {
				$custom_css	.= $options['custom_css'] . "\n";
			}

			if ( '' != $custom_css ){
				echo '<!-- refreshing cache -->' . "\n";

				$custom_css = '<!-- '.get_bloginfo('name').' inline CSS Styles -->' . "\n" . '<style type="text/css" media="screen" rel="CT Custom CSS">' . "\n" . $custom_css;

				$custom_css .= '</style>' . "\n";

			}

			set_transient( 'clean_business_custom_css', htmlspecialchars_decode( $custom_css ), 86940 );
		}

		echo $custom_css;
	}
endif; //clean_business_custom_css
add_action( 'wp_head', 'clean_business_custom_css', 101  );

if ( ! function_exists( 'clean_business_excerpt_length' ) ) :
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_excerpt_length( $length ) {
		$excerpt_length = apply_filters( 'clean_business_get_option', 'excerpt_length' );
		return $excerpt_length;
	}
endif; //clean_business_excerpt_length
add_filter( 'excerpt_length', 'clean_business_excerpt_length' );

if ( ! function_exists( 'clean_business_continue_reading' ) ) :
	/**
	 * Returns a "Custom Continue Reading" link for excerpts
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_continue_reading() {
		$excerpt_more_text = apply_filters( 'clean_business_get_option', 'excerpt_more_text' );

		return ' <span class="readmore"><a class="more-link" href="' . esc_url( get_permalink() ) . '">' . $excerpt_more_text . '</a></span>';
	}
endif; //clean_business_continue_reading
add_filter( 'excerpt_more', 'clean_business_continue_reading' );

if ( ! function_exists( 'clean_business_more_link' ) ) :
	/**
	 * Replacing Continue Reading link to the_content more.
	 *
	 * function tied to the the_content_more_link filter hook.
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_more_link( $more_link, $more_link_text ) {
	 	$more_tag_text = apply_filters( 'clean_business_get_option', 'excerpt_more_text' );

		return str_replace( $more_link_text, $more_tag_text, $more_link );
	}
endif; //clean_business_more_link
add_filter( 'the_content_more_link', 'clean_business_more_link', 10, 2 );

if ( ! function_exists( 'clean_business_rss_redirect' ) ) :
	/**
	 * Redirect WordPress Feeds To FeedBurner
	 *
	 * @action template_redirect
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_rss_redirect() {
		$feed_redirect = apply_filters( 'clean_business_get_option', 'feed_redirect' );

	    if ( $feed_redirect ) {
			$url = 'Location: '. $feed_redirect;

			if ( is_feed() && !preg_match('/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
				header( esc_url( $url ) );
				header('HTTP/1.1 302 Temporary Redirect');
			}
		}
	}
endif; //clean_business_rss_redirect
add_action( 'template_redirect', 'clean_business_rss_redirect' );

/**
 * Footer Text
 *
 * @get footer text from theme options and display them accordingly
 * @display footer_text
 * @action clean_business_footer
 *
 * @since Clean Business 1.0
 */
function clean_business_footer_content() {
	//clean_business_flush_transients();
	if ( ( !$output = get_transient( 'clean_business_footer_content' ) ) ) {
		echo '<!-- refreshing cache -->';

		// get the data value from theme options
		$footer_left_content = apply_filters( 'clean_business_get_option', 'footer_left_content' );

		$footer_right_content = apply_filters( 'clean_business_get_option', 'footer_right_content' );

		if ( empty( $footer_left_content ) &&  empty( $footer_right_content )) {
			return false;
		}
		else {
			//Replace predefined tags in footer with dynamic content
			$search = array( '[the-year]', '[site-link]' );

	        $replace = array( esc_attr( date_i18n( __( 'Y', 'clean-business-pro' ) ) ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

	        $footer_left_content = str_replace( $search, $replace, $footer_left_content );

			$class = 'site-info container';

			if ( !empty( $footer_left_content ) && !empty( $footer_right_content ) ){
	    		$class .= " two";
	    	}
	    	else {
	    		$class .= " one";
	    	}

	    	$output .=  '
	    	<div id="site-generator" class="'. $class . '">
	    		<div class="row">';

			    	if ( !empty( $footer_left_content ) ) {
						$output .= '<div id="footer-left-content" class="copyright col-md-6">' . $footer_left_content . '</div>';
					}

					if ( !empty( $footer_right_content ) ) {
						$output .= '<div id="footer-right-content" class="powered col-md-6">' . $footer_right_content . '</div>';
					}

			$output .=  '
				</div><!-- .row -->
			</div><!-- #site-generator -->';

	    	set_transient( 'clean_business_footer_content', $output, 86940 );
	    }
    }

    echo $output;
}
add_action( 'clean_business_footer', 'clean_business_footer_content', 100 );

/**
 * Alter the query for the main loop in homepage
 *
 * @action pre_get_posts
 *
 * @since Clean Business 1.0
 */
function clean_business_alter_home( $query ){
	$cats = apply_filters( 'clean_business_get_option', 'front_page_category' );
	if ( is_array( $cats  ) && !in_array( '0', $cats  ) ) {
    	$cats = (array) $cats ;
    	if ( defined( "ICL_LANGUAGE_CODE" ) ) {
		    $category = array();
		    foreach( $cats as $cat ){
		    	$category[] = apply_filters( 'wpml_object_id', $cat, 'category', true );
		    }
		    $cats = $category;
		}
    }
    else{
    	$cats = '0';
    }

	$exclude_slider_post = apply_filters( 'clean_business_get_option', 'exclude_slider_post' );

	if ( $exclude_slider_post) {
		$post_list = array();	// list of valid post ids

		$quantity  = apply_filters( 'clean_business_get_option', 'featured_slider_number' );

		for( $i = 1; $i <= $quantity; $i++ ){
			$post_id = (int) apply_filters( 'clean_business_get_option', 'featured_slider_post_' . $i );

			if( $post_id > 0 ) {
				$post_list = array_merge( $post_list, array( $post_id ) );
			}
		}

	    if ( !empty( $post_list ) ) {
			if( $query->is_main_query() && $query->is_home() ) {
				$query->query_vars['post__not_in'] = $post_list;
			}
		}
	}

	if ( is_array( $cats ) && !in_array( '0', $cats ) ) {
		if( $query->is_main_query() && $query->is_home() ) {
			$query->query_vars['category__in'] =  $cats;
		}
	}
}
add_action( 'pre_get_posts','clean_business_alter_home' );

if ( ! function_exists( 'clean_business_archive_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply create your own clean_business_archive_content_image(), and that function will be used instead.
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_archive_content_image() {
		$content_layout = apply_filters( 'clean_business_get_option', 'content_layout' );
		$theme_layout   = clean_business_get_theme_layout();

		if ( has_post_thumbnail() && 'full-content' != $content_layout ) { ?>
			<div class="entry-thumb">
	            <a rel="bookmark" href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
	            <?php
	            	if ( 'no-sidebar-full-width' == $theme_layout ) {
	            		if ( 'excerpt-image-left' == $content_layout  || 'excerpt-image-right' == $content_layout ) {
	            			the_post_thumbnail( 'post-thumbnail' );
	            		}
	            		else {
		                	the_post_thumbnail( 'full' );
						}
					}
					else {
						if ( 'excerpt-image-left' == $content_layout  || 'excerpt-image-right' == $content_layout ) {
		                     the_post_thumbnail( 'clean-business-square' );
		                }
		                else {
		                	the_post_thumbnail( 'clean-business-featured' );
		                }
					}
				?>
				</a>
	        </div><!-- .entry-thumb -->
	   	<?php
		}
	}
endif; //clean_business_archive_content_image
add_action( 'clean_business_before_entry_container', 'clean_business_archive_content_image', 10 );


if ( ! function_exists( 'clean_business_single_content_image' ) ) :
	/**
	 * Template for Featured Image in Single Post
	 *
	 * To override this in a child theme
	 * simply create your own clean_business_single_content_image(), and that function will be used instead.
	 *
	 * @since Clean Business 1.0
	 */
	function clean_business_single_content_image() {
		global $post, $wp_query;

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();
		if( $post) {
	 		if ( is_attachment() ) {
				$parent = $post->post_parent;
				$individual_featured_image = get_post_meta( $parent,'clean-business-featured-image', true );
			} else {
				$individual_featured_image = get_post_meta( $page_id,'clean-business-featured-image', true );
			}
		}

		if( empty( $individual_featured_image ) || ( !is_page() && !is_single() ) ) {
			$individual_featured_image = 'default';
		}

		// Getting data from Theme Options
	   	$featured_image = apply_filters( 'clean_business_get_option', 'single_post_image_layout' );

		if ( ( 'disabled' == $individual_featured_image  || '' == get_the_post_thumbnail() || ( $individual_featured_image=='default' && 'disabled' == $featured_image ) ) ) {
			echo '<!-- Page/Post Single Image Disabled or No Image set in Post Thumbnail -->';
			return false;
		}
		else {
			$class = '';

			if ( 'default' == $individual_featured_image ) {
				$class = $featured_image;
			}
			else {
				$class = 'from-metabox ' . $individual_featured_image;
			}

			?>
			<div class="entry-thumb <?php echo $class; ?>">
                <?php the_post_thumbnail( $individual_featured_image ); ?>
	        </div><!-- .entry-thumb -->
	   	<?php
		}
	}
endif; //clean_business_single_content_image
add_action( 'clean_business_before_post_container', 'clean_business_single_content_image', 10 );
add_action( 'clean_business_before_page_container', 'clean_business_single_content_image', 10 );

if ( ! function_exists( 'clean_business_promotion_headline' ) ) :
	/**
	 * Template for Promotion Headline
	 *
	 * To override this in a child theme
	 * simply create your own clean_business_promotion_headline(), and that function will be used instead.
	 *
	 * @uses clean_business_before_main action to add it in the header
	 * @since Clean Business 1.0
	 */
	function clean_business_promotion_headline() {
		global $post, $wp_query;
	   	$enable_promotion = apply_filters( 'clean_business_get_option', 'promotion_headline_option' );


		// Front page displays in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		 if ( 'entire-site' == $enable_promotion || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' ==  $enable_promotion  ) ) {
			get_sidebar( 'promotion-headline' );
		}
	}
endif; // clean_business_promotion_featured_content
add_action( 'clean_business_before_content', 'clean_business_promotion_headline', 30 );

if ( ! function_exists( 'clean_business_scrollup' ) ) {
	/**
	 * This function loads Scroll Up Navigation
	 *
	 * @action clean_business_footer action
	 * @uses set_transient and delete_transient
	 */
	function clean_business_scrollup() {
		//clean_business_flush_transients();
		if ( !$output = get_transient( 'clean_business_scrollup' ) ) {
			// get the data value from theme options
			$disable_scrollup = apply_filters( 'clean_business_get_option', 'disable_scrollup' );
			echo '<!-- refreshing cache -->';

			//site stats, analytics header code
			if ( !$disable_scrollup ) {
				$output =  '<a class="scrollup"><i class="fa fa-angle-up"></i></a>' ;
			}

			set_transient( 'clean_business_scrollup', $output, 86940 );
		}
		echo $output;
	}
}
add_action( 'clean_business_footer', 'clean_business_scrollup', 20 );

/**
 * Return registered image sizes.
 *
 * Return a two-dimensional array of just the additionally registered image sizes, with width, height and crop sub-keys.
 *
 * @since 1.0
 *
 * @global array $_wp_additional_image_sizes Additionally registered image sizes.
 *
 * @return array Two-dimensional, with width, height and crop sub-keys.
 */
function clean_business_get_additional_image_sizes() {
	global $_wp_additional_image_sizes;

	if ( $_wp_additional_image_sizes ) {
		return $_wp_additional_image_sizes;
	}

	return array();
}

/**
 * Display Multiple Select type for and array of categories
 *
 * @param  [string] $name  [field name]
 * @param  [string] $id    [field_id]
 * @param  [array] $selected    [selected values]
 * @param  string $label [label of the field]
 */
function clean_business_dropdown_categories( $name, $id, $selected, $label = '' ) {
	$dropdown = wp_dropdown_categories(
		array(
			'name'             => $name,
			'echo'             => 0,
			'hide_empty'       => false,
			'show_option_none' => false,
			'hierarchical'       => 1,
		)
	);

	if ( '' != $label ) {
		echo '<label for="' . $id . '">
			'. $label .'
			</label>';
	}

	$dropdown = str_replace('<select', '<select multiple = "multiple" style = "height:120px; width: 100%" ', $dropdown );

	foreach( $selected as $selected ) {
		$dropdown = str_replace( 'value="'. $selected .'"', 'value="'. $selected .'" selected="selected"', $dropdown );
	}

	echo $dropdown;

	echo '<span class="description">'. esc_html__( 'Hold down the Ctrl (windows) / Command (Mac) button to select multiple options.', 'clean-business-pro' ) . '</span>';
}

if ( ! function_exists( 'clean_business_get_highlight_meta' ) ) :
	/**
	 * Returns HTML with meta information for the categories, tags, date and author.
	 *
	 * @param [boolean] $hide_category Adds screen-reader-text class to category meta if true
	 * @param [boolean] $hide_tags Adds screen-reader-text class to tag meta if true
	 * @param [boolean] $hide_posted_by Adds screen-reader-text class to date meta if true
	 * @param [boolean] $hide_author Adds screen-reader-text class to author meta if true
	 *
	 * @since Clean Business Pro 1.0
	 */
	function clean_business_get_highlight_meta( $hide_category = false, $hide_tags = false, $hide_posted_by = false, $hide_author = false ) {
		$output = '<p class="entry-meta">';

		if ( 'post' == get_post_type() ) {

			$class = $hide_category ? 'screen-reader-text' : '';

			$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'clean-business-pro' ) );
			if ( $categories_list && clean_business_categorized_blog() ) {
				$output .= sprintf( '<span class="cat-links ' . $class . '">%1$s%2$s</span>',
					sprintf( _x( '<span class="screen-reader-text">Categories</span>', 'Used before category names.', 'clean-business-pro' ) ),
					$categories_list
				);
			}

			$class = $hide_tags ? 'screen-reader-text' : '';

			$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'clean-business-pro' ) );
			if ( $tags_list ) {
				$output .= sprintf( '<span class="tags-links ' . $class . '"><i class="fa fa-tags"></i>%1$s%2$s</span>',
					sprintf( _x( '<span class="screen-reader-text">Tags</span>', 'Used before tag names.', 'clean-business-pro' ) ),
					$tags_list
				);
			}

			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$class = $hide_posted_by ? 'screen-reader-text' : '';

			$output .= sprintf( '<span class="posted-on ' . $class . '">%1$s<a href="%2$s" rel="bookmark">%3$s</a></span>',
				sprintf( _x( '<span class="screen-reader-text">Posted on</span>', 'Used before publish date.', 'clean-business-pro' ) ),
				esc_url( get_permalink() ),
				$time_string
			);

			if ( is_singular() || is_multi_author() ) {
				$class = $hide_author ? 'screen-reader-text' : '';

				$output .= sprintf( '<span class="byline ' . $class . '"><span class="author vcard">%1$s<a class="url fn n" href="%2$s">%3$s</a></span></span>',
					sprintf( _x( '<span class="screen-reader-text">Author</span>', 'Used before post author name.', 'clean-business-pro' ) ),
					esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
					esc_html( get_the_author() )
				);
			}
		}

		$output .= '</p><!-- .entry-meta -->';

		return $output;
	}
endif; //clean_business_get_highlight_meta

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @param [string/array] $src set true to return only image source
 * @return [string] image html
 *
 * @since Clean Business 1.0
 */

function clean_business_get_first_image( $postID, $size, $attr, $src = false ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if( isset( $matches [1] [0] ) ) {
		//Get first image
		$first_img = $matches [1] [0];

		if ( $src ) {
			//Return url of src is true
			return $first_img;
		}

		return '<img class="wp-post-image" src="'. $first_img .'">';
	}

	return false;
}


if ( ! function_exists( 'clean_business_before_content_sidebar' ) ) :
/**
 * Before Content Sidebar
 *
 * @since Clean Magazine 1.0
 */
function clean_business_before_content_sidebar() {
	get_sidebar( 'before-content' );
}
endif;
add_action( 'clean_business_before_content', 'clean_business_before_content_sidebar', 100 );


if ( ! function_exists( 'clean_business_after_content_sidebar' ) ) :
/**
 * After Content Sidebar
 *
 * @since Clean Magazine 1.0
 */
function clean_business_after_content_sidebar() {
	get_sidebar( 'after-content' );
}
endif;
add_action( 'clean_business_after_content', 'clean_business_after_content_sidebar', 9 );
